@@ -1,6 +1,6 @@
 ###
 ### $Rev: 51 $
-### $Release: 0.6.0 $
+### $Release: 0.6.1 $
 ### copyright(c) 2005 kuwata-lab all rights reserved.
 ###
 
@@ -42,7 +42,7 @@ module Kwalify
 
       def parse()
          data = parse_child(0)
-         if data == nil && @end_flag == '---'
+         if data.nil? && @end_flag == '---'
             data = parse_child(0)
          end
          resolve_aliases(data) unless @aliases.empty?
@@ -147,8 +147,8 @@ module Kwalify
       def _getchar
          @index += 1
          ch = @sbuf[@index]
-         while ch == nil
-            break if (line = getline()) == nil
+         while ch.nil?
+            break if (line = getline()).nil?
             reset_sbuf(line)
             @index += 1
             ch = @sbuf[@index]
@@ -238,18 +238,18 @@ module Kwalify
          ch = current_char
          assert ch == ?] || ch == ?}
          ch = getchar_or_nl()
-         unless ch == ?\n || ch == ?# || ch == nil
+         unless ch == ?\n || ch == ?# || ch.nil?
             #* key=:flow_hastail  msg="flow style sequence is closed but got '%s'."
             raise syntax_error(:flow_hastail, [ch.chr])
          end
-         getline() if ch != nil
+         getline() unless ch.nil?
          return data
       end
 
       def parse_flow(depth)
          ch = current_char()
          #ch = getchar()
-         if ch == nil
+         if ch.nil?
             #* key=:flow_eof  msg="found EOF when parsing flow style."
             rase syntax_error(:flow_eof)
          end
@@ -342,8 +342,33 @@ module Kwalify
          when ?", ?'         #"
             endch = ch
             s = ''
-            while (ch = _getchar()) != nil && ch != endch
-               s << ch.chr
+            while !(ch = _getchar()).nil? && ch != endch
+               if ch == ?\\
+                  ch = _getchar()
+                  if ch.nil?
+                     #* key=:flow_str_notclosed  msg="%s: string not closed."
+                     raise syntax_error(:flow_str_notclosed, endch == ?" ? "'\"'" : '"\'"')
+                  end
+                  if endch == ?"
+                     case ch
+                     when ?\\ ;  s << "\\"
+                     when ?"  ;  s << "\""
+                     when ?n  ;  s << "\n"
+                     when ?r  ;  s << "\r"
+                     when ?t  ;  s << "\t"
+                     when ?b  ;  s << "\b"
+                     else     ;  s << "\\" << ch.chr
+                     end
+                  elsif endch == ?'
+                     case ch
+                     when ?\\ ;  s << '\\'
+                     when ?'  ;  s << '\''
+                     else     ;  s << '\\' << ch.chr
+                     end
+                  end
+               else
+	          s << ch.chr
+	       end
             end
             getchar()
             scalar = s
